Class: AmoebaDeployTools::Command
- Inherits:
-
Thor
- Object
- Thor
- AmoebaDeployTools::Command
- Includes:
- AmoebaDeployTools::Concerns::Hooks
- Defined in:
- lib/amoeba_deploy_tools/command.rb
Instance Method Summary collapse
-
#initialize(args = [], options = {}, config = {}) ⇒ Command
constructor
Note that all subcommands will inherit this class.
Methods included from AmoebaDeployTools::Concerns::Hooks
Constructor Details
#initialize(args = [], options = {}, config = {}) ⇒ Command
Note that all subcommands will inherit this class. This means any setup done in here will be duplicated if it runs at initialization (since the main command and subcommand are both evaluated at runtime). Thus, it’s important not to put anything in the constructor. If you wish to setup any global state, do so in the Amoeba class initializer.
17 18 19 |
# File 'lib/amoeba_deploy_tools/command.rb', line 17 def initialize(args=[], ={}, config={}) super end |